@@ -1,4 +1,4 @@
-/* $Id: address.c,v 1.57 2009-09-24 03:58:18 rikster5 Exp $ */
+/* $Id: address.c,v 1.59 2010-03-07 21:26:51 rikster5 Exp $ */
 
 /*******************************************************************************
  * address.c
@@ -48,7 +48,7 @@ static int glob_sort_rule;
 int addr_sort_order;
 
 /****************************** Main Code *************************************/
-int address_compare(const void *v1, const void *v2)
+static int address_compare(const void *v1, const void *v2)
 {
    AddressList **al1, **al2;
    struct Address *a1, *a2;
@@ -84,7 +84,7 @@ int address_compare(const void *v1, const void *v2)
 
    last_cmp1=last_cmp2=0;
 
-   if (!(glob_sort_rule & SORT_JAPANESE) | (glob_sort_rule & SORT_JOS)) { /* normal */
+   if (!(glob_sort_rule & SORT_JAPANESE) || (glob_sort_rule & SORT_JOS)) { /* normal */
       while (last_cmp1 < 3 && last_cmp2 < 3) {
 	 str1=str2=NULL;
          /* Find the next non-blank field to use for sorting */
@@ -240,7 +240,7 @@ int address_compare(const void *v1, const void *v2)
 }
 
 /* sort_order: SORT_ASCENDING | SORT_DESCENDING */
-int address_sort(AddressList **al, int sort_order)
+static int address_sort(AddressList **al, int sort_order)
 {
    AddressList *temp_al;
    AddressList **sort_al;
