@@ -1,10 +1,10 @@
-/* $Id: category.c,v 1.32 2008/06/19 04:12:07 rikster5 Exp $ */
+/* $Id: category.c,v 1.35 2010-03-03 12:09:43 rousseau Exp $ */
 
 /*******************************************************************************
  * category.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 2002 by Judd Montgomery
+ * Copyright (C) 2009-2010 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ struct dialog_cats_data {
 };
 
 /****************************** Main Code *************************************/
-int count_records_in_cat(char *db_name, int cat_index)
+static int count_records_in_cat(char *db_name, int cat_index)
 {
    GList *records;
    GList *temp_list;
@@ -86,7 +86,10 @@ int count_records_in_cat(char *db_name, int cat_index)
       }
 
       if (!br->buf) continue;
-      if ((br->rt==DELETED_PALM_REC) || (br->rt==MODIFIED_PALM_REC)) continue;
+      if ((br->rt==DELETED_PALM_REC)  || 
+          (br->rt==DELETED_PC_REC)    || 
+          (br->rt==MODIFIED_PALM_REC)) 
+         continue;
       if ((br->attrib & 0x0F) != cat_index) continue;
 
       count++;
@@ -99,7 +102,7 @@ int count_records_in_cat(char *db_name, int cat_index)
    return count;
 }
 
-int edit_cats_delete_cats_pc3(char *DB_name, int cat)
+static int edit_cats_delete_cats_pc3(char *DB_name, int cat)
 {
    char local_pc_file[FILENAME_MAX];
    FILE *pc_in;
@@ -154,7 +157,7 @@ int edit_cats_delete_cats_pc3(char *DB_name, int cat)
 
 /* Helper routine to change categories.
  * Function changes category regardless of record type */
-int _edit_cats_change_cats_pc3(char *DB_name, 
+static int _edit_cats_change_cats_pc3(char *DB_name, 
                                int old_cat, int new_cat, 
                                int swap)
 {
@@ -288,7 +291,7 @@ int edit_cats_change_cats_pdb(char *DB_name, int old_cat, int new_cat)
  * option will also change new_index records to old_index ones.
  * Returns the number of records where the category was changed.
  */
-int _change_cat_pdb(char *DB_name, int old_index, int new_index, int swap)
+static int _change_cat_pdb(char *DB_name, int old_index, int new_index, int swap)
 {
    char local_pdb_file[FILENAME_MAX];
    char full_local_pdb_file[FILENAME_MAX];
@@ -381,7 +384,7 @@ int pdb_file_swap_indexes(char *DB_name, int old_cat, int new_cat)
  *  It does not modify a local pdb file.
  *  It does this by writing a modified record to the pc3 file.
  */
-int edit_cats_delete_cats_pdb(char *DB_name, int cat)
+static int edit_cats_delete_cats_pdb(char *DB_name, int cat)
 {
    jp_logf(JP_LOG_DEBUG, "edit_cats_delete_cats_pdb\n");
 
@@ -656,7 +659,7 @@ static void cb_edit_button(GtkWidget *widget, gpointer data)
 }
 
 
-void cb_clist_edit_cats(GtkWidget *widget,
+static void cb_clist_edit_cats(GtkWidget *widget,
 			gint row, gint column,
 			GdkEventButton *event, gpointer data)
 {
