@@ -1,4 +1,4 @@
-/* $Id: export_gui.c,v 1.20 2008/04/27 16:30:19 rikster5 Exp $ */
+/* $Id: export_gui.c,v 1.25 2010-03-03 14:42:03 rousseau Exp $ */
 
 /*******************************************************************************
  * export_gui.c
@@ -20,30 +20,38 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
 #include <sys/stat.h>
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
 #include <pi-appinfo.h>
+
+#include "i18n.h"
 #include "utils.h"
 #include "log.h"
 #include "prefs.h"
 #include "export.h"
 
+/********************************* Constants **********************************/
+#define NUM_CAT_ITEMS 16
 
 #define BROWSE_OK     1
 #define BROWSE_CANCEL 2
 
-#define NUM_CAT_ITEMS 16
-
+/******************************* Global vars **********************************/
 static GtkWidget *export_clist;
-int export_category;
+static int export_category;
 
 static int glob_export_browse_pressed;
 static int glob_pref_export;
 
+static GtkWidget *export_radio_type[10];
+static int glob_export_type;
+static GtkWidget *save_as_entry;
+
+/****************************** Prototypes ************************************/
 static void (*glob_cb_export_menu)(GtkWidget *clist, int category);
 void (*glob_cb_export_done)(GtkWidget *widget,
 			    const char *filename);
@@ -52,24 +60,23 @@ void (*glob_cb_export_ok)(GtkWidget *export_window,
 			  int type,
 			  const char *filename);
 
-/* Browse GUI */
+/****************************** Main Code *************************************/
+/* 
+ * Browse GUI
+ */
 static gboolean cb_export_browse_destroy(GtkWidget *widget)
 {
    gtk_main_quit();
    return FALSE;
 }
 
-static void
-cb_export_browse_cancel(GtkWidget *widget,
-			gpointer   data)
+static void cb_export_browse_cancel(GtkWidget *widget, gpointer data)
 {
    glob_export_browse_pressed=BROWSE_CANCEL;
    gtk_widget_destroy(data);
 }
 
-static void
-cb_export_browse_ok(GtkWidget *widget,
-		    gpointer   data)
+static void cb_export_browse_ok(GtkWidget *widget, gpointer data)
 {
    const char *sel;
 
@@ -85,7 +92,7 @@ int export_browse(GtkWidget *main_window, int pref_export)
 {
    GtkWidget *filesel;
    const char *svalue;
-   char dir[MAX_PREF_VALUE+2];
+   char dir[MAX_PREF_LEN+2];
    int i;
 
    glob_export_browse_pressed = 0;
@@ -137,11 +144,6 @@ int export_browse(GtkWidget *main_window, int pref_export)
 /*
  * Start Export code
  */
-
-static GtkWidget *save_as_entry;
-static GtkWidget *export_radio_type[10];
-static int glob_export_type;
-
 static gboolean cb_export_destroy(GtkWidget *widget)
 {
    const char *filename;
@@ -155,8 +157,7 @@ static gboolean cb_export_destroy(GtkWidget *widget)
    return FALSE;
 }
 
-static void cb_ok(GtkWidget *widget,
-		  gpointer   data)
+static void cb_ok(GtkWidget *widget, gpointer data)
 {
    const char *filename;
 
@@ -169,9 +170,7 @@ static void cb_ok(GtkWidget *widget,
    gtk_widget_destroy(data);
 }
 
-static void
-cb_export_browse(GtkWidget *widget,
-		 gpointer   data)
+static void cb_export_browse(GtkWidget *widget, gpointer data)
 {
    int r;
    const char *svalue;
@@ -185,21 +184,17 @@ cb_export_browse(GtkWidget *widget,
    }
 }
 
-static void
-cb_export_quit(GtkWidget *widget,
-	       gpointer   data)
+static void cb_export_quit(GtkWidget *widget, gpointer data)
 {
    gtk_widget_destroy(data);
 }
 
-static void
-cb_export_type(GtkWidget *widget,
-	       gpointer   data)
+static void cb_export_type(GtkWidget *widget, gpointer data)
 {
    glob_export_type=GPOINTER_TO_INT(data);
 }
 
-void cb_export_category(GtkWidget *item, int selection)
+static void cb_export_category(GtkWidget *item, int selection)
 {
    if ((GTK_CHECK_MENU_ITEM(item))->active) {
       export_category = selection;
@@ -282,7 +277,7 @@ int export_gui(GtkWidget *main_window,
 
    /* Put the export category menu up */
    make_category_menu(&category_menu, cat_menu_item, sort_l,
-		      cb_export_category, TRUE);
+		      cb_export_category, TRUE, FALSE);
    gtk_box_pack_start(GTK_BOX(vbox), category_menu, FALSE, FALSE, 0);
 
    /* Put the record list window up */
@@ -302,12 +297,11 @@ int export_gui(GtkWidget *main_window,
 
    gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(export_clist));
 
-
-   /* Export Type Buttons */
+   /* Export Type buttons */
    group = NULL;
    for (i=0; i<100; i++) {
       if (type_text[i]==NULL) break;
-      export_radio_type[i] = gtk_radio_button_new_with_label(group, type_text[i]);
+      export_radio_type[i] = gtk_radio_button_new_with_label(group, _(type_text[i]));
       group = gtk_radio_button_group(GTK_RADIO_BUTTON(export_radio_type[i]));
       gtk_box_pack_start(GTK_BOX(vbox), export_radio_type[i], FALSE, FALSE, 0);
       gtk_signal_connect(GTK_OBJECT(export_radio_type[i]), "pressed",
@@ -330,31 +324,26 @@ int export_gui(GtkWidget *main_window,
       gtk_entry_set_text(GTK_ENTRY(save_as_entry), svalue);
    }
    gtk_box_pack_start(GTK_BOX(hbox), save_as_entry, TRUE, TRUE, 0);
+
+   /* Browse button */
    button = gtk_button_new_with_label(_("Browse"));
    gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_export_browse), export_window);
 
+   /* Cancel/OK buttons */
    hbox = gtk_hbutton_box_new();
    gtk_container_set_border_width(GTK_CONTAINER(hbox), 12);
    gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
    gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 6);
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-#ifdef ENABLE_GTK2
    button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-#else
-   button = gtk_button_new_with_label(_("Cancel"));
-#endif
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_export_quit), export_window);
 
-#ifdef ENABLE_GTK2
    button = gtk_button_new_from_stock(GTK_STOCK_OK);
-#else
-   button = gtk_button_new_with_label(_("OK"));
-#endif
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_ok), export_window);
@@ -367,11 +356,8 @@ int export_gui(GtkWidget *main_window,
 
    gtk_clist_select_all(GTK_CLIST(export_clist));
 
-
    gtk_main();
 
    return EXIT_SUCCESS;
 }
-/*
- * End Export code
- */
+
