@@ -1,4 +1,7 @@
-/* memo.h
+/* $Id: memo.h,v 1.8 2009-11-08 17:12:10 rousseau Exp $ */
+
+/*******************************************************************************
+ * memo.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef __MEMO_H__
 #define __MEMO_H__
 
@@ -30,7 +34,7 @@ int get_memos2(MemoList **memo_list, int sort_order,
 int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
 		  unsigned int *unique_id);
 
-int memo_print();
+int memo_print(void);
 int memo_import(GtkWidget *window);
 int memo_export(GtkWidget *window);
 
