@@ -1,4 +1,4 @@
-/* $Id: prefs.c,v 1.83 2009/02/14 17:32:31 rousseau Exp $ */
+/* $Id: prefs.c,v 1.87 2010-03-03 12:49:59 rousseau Exp $ */
 
 /*******************************************************************************
  * prefs.c
@@ -150,6 +150,7 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"todo_note_pane", INTTYPE, INTTYPE, 200, NULL, 0},
      {"expense_sort_column", INTTYPE, INTTYPE, 0, NULL, 0},
      {"expense_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
+     {"keyr_export_filename", CHARTYPE, CHARTYPE, 0, NULL, 0},
 };
 
 struct name_list {
@@ -160,7 +161,7 @@ struct name_list {
 static struct name_list *dir_list=NULL;
 
 /****************************** Main Code *************************************/
-void pref_init()
+void pref_init(void)
 {
    int i;
 
@@ -171,6 +172,10 @@ void pref_init()
 
    for (i=0; i<NUM_PREFS; i++) {
       switch (i) {
+       case PREF_PORT:
+	 glob_prefs[i].svalue=strdup("usb:");
+	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
+         break;
        case PREF_RCFILE:
 	 glob_prefs[i].svalue=strdup(EPN"rc.default");
 	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
@@ -609,7 +614,7 @@ long get_pref_int_default(int which, long defval)
  * Treats src==NULL as ""
  * Writes NULL at end of string
  */
-char *pref_lstrncpy_realloc(char **dest, const char *src, int *size, int max_size)
+static char *pref_lstrncpy_realloc(char **dest, const char *src, int *size, int max_size)
 {
    int new_size, len;
    const char null_str[]="";
@@ -714,7 +719,7 @@ int set_pref_possibility(int which, long n, int save)
    return r;
 }
 
-static int validate_glob_prefs()
+static int validate_glob_prefs(void)
 {
    int i, r;
    char svalue[MAX_PREF_LEN];
@@ -904,7 +909,7 @@ int jp_pref_read_rc_file(char *filename, prefType prefs[], int num_prefs)
    return EXIT_SUCCESS;
 }
 
-int pref_read_rc_file()
+int pref_read_rc_file(void)
 {
    int r;
 
@@ -942,7 +947,7 @@ int jp_pref_write_rc_file(char *filename, prefType prefs[], int num_prefs)
    return EXIT_SUCCESS;
 }
 
-int pref_write_rc_file()
+int pref_write_rc_file(void)
 {
    return jp_pref_write_rc_file(EPN".rc", glob_prefs, NUM_PREFS);
 }
