@@ -1,4 +1,4 @@
-/* $Id: print_headers.c,v 1.8 2008/06/19 04:12:07 rikster5 Exp $ */
+/* $Id: print_headers.c,v 1.10 2010-03-03 14:42:03 rousseau Exp $ */
 
 /*******************************************************************************
  * print_headers.c
@@ -25,6 +25,8 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "print_headers.h"
+
 /****************************** Main Code *************************************/
 void print_common_prolog(FILE *f)
 {
@@ -744,7 +746,7 @@ void print_month_header(FILE *f)
         "        /FDOM1          edef\n"
         "        /MonthName1     edef\n"
         "\n"
-        "        Col 5 lt {\n"
+        "        Col 5 lt Row 1 gt or {\n"
         "            Row 0 ne {\n"
         "                5 4 MonthName1 NumDays1 FDOM1 SmallMonth\n"
         "                6 4 MonthName2 NumDays2 FDOM2 SmallMonth\n"
