@@ -1,4 +1,7 @@
-/* print_logo.c
+/* $Id: print_logo.c,v 1.10 2010-03-03 14:42:03 rousseau Exp $ */
+
+/*******************************************************************************
+ * print_logo.c
  *
  * Copyright (C) 2001 by Colin Brough
  *
@@ -15,16 +18,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
 #include <stdio.h>
-#ifdef HAVE_LOCALE_H
-# include <locale.h>
-#endif
-/*----------------------------------------------------------------------*/
 
-void print_logo_data(FILE *f)
+#include "print_logo.h"
+
+/****************************** Main Code *************************************/
+static void print_logo_data(FILE *f)
 {
     fputs(
 	"fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff"
@@ -426,13 +429,8 @@ void print_logo_data(FILE *f)
 	"\n\n", f);
 }
 
-/*----------------------------------------------------------------------*/
-
 void print_logo(FILE *f, int x, int y, float size)
 {
-#ifdef HAVE_LOCALE_H
-   setlocale(LC_ALL,"C");
-#endif
     fprintf(f,
 	    "%%----------------------------------------\n"
 	    "%% Now the jpilot penguin logo; this is data\n"
@@ -452,7 +450,5 @@ void print_logo(FILE *f, int x, int y, float size)
 	  "%%----------------------------------------\n"
 	  "%% End of logo\n"
 	  "%%----------------------------------------\n", f);
-#ifdef HAVE_LOCALE_H
-   setlocale(LC_ALL,"");
-#endif
 }
+
