@@ -1,4 +1,4 @@
-/* $Id: restore_gui.c,v 1.26 2008/06/19 04:12:07 rikster5 Exp $ */
+/* $Id: restore_gui.c,v 1.28 2010-03-03 12:50:00 rousseau Exp $ */
 
 /*******************************************************************************
  * restore_gui.c
@@ -36,6 +36,7 @@
 #include "prefs.h"
 #include "sync.h"
 #include "log.h"
+#include "restore.h"
 
 /******************************* Global vars **********************************/
 static GtkWidget *user_entry;
@@ -191,7 +192,7 @@ static int populate_clist_sub(char *path, int check_for_dups, int check_exts)
    return num;
 }
 
-static int populate_clist()
+static int populate_clist(void)
 {
    char path[FILENAME_MAX];
 
